from datetime import date, timedelta
from django import forms
from django.core.validators import RegexValidator


class SanitizeInputForm(forms.Form):
    nama = forms.CharField(
        min_length=1,
        max_length=255, 
        required=True,
        widget=forms.TextInput(attrs={'placeholder': 'Nama Lengkap'}),
        validators=[
            RegexValidator(
                regex=r'^[a-zA-Z0-9._-]+$', 
                message='Hanya boleh huruf, angka ,dan dan simbol (., _, -).'
            )
        ]
    )
    
    password = forms.CharField(
        min_length=8,
        max_length=255, 
        required=True,
        help_text="Minimal 8 karakter dengan huruf, angka, dan karakter spesial.",
        widget=forms.PasswordInput(attrs={'placeholder': 'Password'}),
        validators=[
            RegexValidator(
                regex=r'^(?=.*[A-Za-z])(?=.*\d)(?=.*[@$!%*#?&-_+()/?,.])[A-Za-z\d@$!%*#?&-_+()/?,.]{8,}$', 
                message='Minimal 8 karakter dengan huruf, angka, dan karakter spesial (@$!%*#?&-_+()/?,.)'
            )
        ]
    )
    
    tanggal_lahir = forms.DateField(
        required=True,
        help_text="Usia minimal 12 tahun.",
        widget=forms.DateInput(attrs={'type': 'date'})
    )

    def clean_tanggal_lahir(self):
        tanggal_lahir = self.cleaned_data.get('tanggal_lahir')
        today = date.today()
        batas_tanggal = tanggal_lahir.replace(year=tanggal_lahir.year + 12)

        if batas_tanggal > today:
            raise forms.ValidationError("Usia minimal harus 12 tahun pada hari ini.")
        
        return tanggal_lahir
    
    nomor_hp = forms.CharField(
        min_length=8,
        max_length=15, 
        required=True,
        help_text="Format: Kode Negara + Nomor (tanpa '+' dan '-'). Contoh: 6212345678",
        widget=forms.TextInput(attrs={'placeholder': 'Nomor HP'}),
        validators=[
            RegexValidator(
                regex=r'^62\d{6,15}$', 
                message='Format: Kode Negara + Nomor (tanpa "+" dan "-"). Contoh: 6212345678'
            )
        ]
    )
    
    email = forms.EmailField(
        required=True,
        help_text="Masukkan email yang valid.",
        widget=forms.EmailInput(attrs={'placeholder': 'Email'})
    )
    
    url_blog = forms.URLField(
        required=True,
        help_text="Masukkan URL Blog yang valid.",
        widget=forms.URLInput(attrs={'placeholder': 'URL Blog'})
    )
    
    deskripsi_diri = forms.CharField(
        min_length=5, 
        max_length=1000,
        required=True,
        help_text="Minimal 5 karakter, maksimal 1000 karakter.",
        widget=forms.Textarea(attrs={'placeholder': 'Deskripsi Diri'})
    )

    golongan_darah = forms.ChoiceField(
        choices=[('A+', 'A+'), ('A-', 'A-'), ('B+', 'B+'), ('B-', 'B-'), ('O+', 'O+'), ('O-', 'O-'), ('AB+', 'AB+'), ('AB-', 'AB-')],
        required=True,
        help_text="Pilih golongan darah yang valid."
    )

    no_polis_asuransi = forms.CharField(
        required=True,
        help_text="Masukkan 5-10 angka.",
        widget=forms.TextInput(attrs={'placeholder': 'No. Polis Asuransi'}),
        validators=[
            RegexValidator(
                regex=r'^\d{5,10}$', 
                message='Masukkan 5-10 angka.'
            )
        ]
    )